@@ -73,12 +73,11 @@ class TestSubscription(BaseTestCase):
             subscriber=SubscriberClient(credentials=service._credentials),
         )
 
-        with patch(
-            "octue.cloud.pub_sub.subscription.Subscription.create",
-            return_value=MockSubscriptionCreationResponse(subscription),
-        ):
+        with patch("google.pubsub_v1.SubscriberClient.create_subscription", new=MockSubscriptionCreationResponse):
             response = subscription.create(allow_existing=True)
 
         self.assertEqual(response._pb.ack_deadline_seconds, 60)
         self.assertEqual(response._pb.expiration_policy.ttl.seconds, THIRTY_ONE_DAYS)
         self.assertEqual(response._pb.message_retention_duration.seconds, SEVEN_DAYS)
+        self.assertEqual(response._pb.retry_policy.minimum_backoff.seconds, 10)
+        self.assertEqual(response._pb.retry_policy.maximum_backoff.seconds, 600)
